pub struct Keypair {
pub ver_key: Verkey,
pub pop: ProofOfPossession,
}Expand description
Keypair consisting of a master secret, the corresponding verkey and the proof of possession Type GPrime denotes group for public key and type G denotes group for proof of possession.
Fields
ver_key: Verkeypop: ProofOfPossessionImplementations
Sourceimpl<'a> Keypair
impl<'a> Keypair
pub fn new<R: RngCore + CryptoRng>( T: u128, generators: &GeneratorSet, rng: &mut R, db: &'a mut dyn SigKeyDb, ) -> Result<(Self, SigkeyManager), PixelError>
Sourcepub fn gen_pop(vk: &Verkey, x: &MasterSecret) -> ProofOfPossession
pub fn gen_pop(vk: &Verkey, x: &MasterSecret) -> ProofOfPossession
Generate proof of possession
Sourcepub fn verify_pop(
pop: &ProofOfPossession,
vk: &Verkey,
gen: &VerkeyGroup,
) -> bool
pub fn verify_pop( pop: &ProofOfPossession, vk: &Verkey, gen: &VerkeyGroup, ) -> bool
Verify proof of possession