pub struct GeneratorSet(pub VerkeyGroup, pub Vec<SignatureGroup>);Expand description
second element is a vector of length l+2 and is of form [h, h_0, h_1, h_2, …, h_l]
Tuple Fields
0: VerkeyGroup1: Vec<SignatureGroup>Implementations
Sourceimpl GeneratorSet
impl GeneratorSet
pub fn new(T: u128, prefix: &str) -> Result<Self, PixelError>
Sourcepub fn create_generators(
T: u128,
prefix: &str,
) -> Result<Vec<SignatureGroup>, PixelError>
pub fn create_generators( T: u128, prefix: &str, ) -> Result<Vec<SignatureGroup>, PixelError>
Returns generators to be used in the protocol. Takes time period T and a prefix string that is used to create generators by hashing the prefix string concatenated with integers. T+1 must be a power of 2.