[][src]Struct pixel_sig::util::GeneratorSet

pub struct GeneratorSet(pub G2, pub Vec<G1>);

second element is a vector with length l+2 and is of form [h, h_0, h_1, h_2, ..., h_l]

Methods

impl GeneratorSet[src]

pub fn new(T: u128, prefix: &str) -> Result<Self, PixelError>[src]

pub fn create_generators(T: u128, prefix: &str) -> Result<Vec<G1>, PixelError>[src]

Returns generators to be used in the protocol. Takes time period T and a prefix string that is used to create generators by hashing the prefix string concatenated with integers. T+1 must be a power of 2.